@@ -61,12 +61,14 @@ let int_of_code = function
 let send_status_line ?(version = http_version) ~(code: status_code) outchan =
   send_status_line' ~version (int_of_code code) outchan
 
-  (* FIXME duplication of code between this and response#addBasicHeaders *)
+let get_basic_headers () =
+  ["Date", Http_misc.date_822 ();
+   "Server", server_string;
+   "Connection", "close"]
+
 let send_basic_headers ?(version = http_version) ~(code: status_code) outchan =
   send_status_line' ~version (int_of_code code) outchan;
-  send_headers
-    ~headers:["Date", Http_misc.date_822 (); "Server", server_string]
-    outchan
+  send_headers ~headers:(get_basic_headers ()) outchan
 
   (** internal: given a status code and an additional body return a string
   representing an HTML document that explains the meaning of given status code.
@@ -304,15 +306,7 @@ let invoke_callback req spec outchan =
   let callback req outchan =
     if spec.auto_close then
       Http_misc.finally
-        (fun () ->
-          (* XXX the pair flush + shutdown is a temporary solution since double
-           * close on a socket make ocaml 3.09.2 segfault (see
-           * http://caml.inria.fr/mantis/view.php?id=4059). The right thing to
-           * do is probably invoke try_close outchan here *)
-          flush outchan;
-          try
-            Unix.shutdown (Unix.descr_of_out_channel outchan) Unix.SHUTDOWN_ALL
-          with Unix.Unix_error(_, "shutdown", "") -> ())
+        (fun () -> try close_out outchan with Sys_error _ -> ())
         (fun () -> spec.callback req outchan) ()
     else
       spec.callback req outchan in
