@@ -2,7 +2,8 @@
 (*
   OCaml HTTP - do it yourself (fully OCaml) HTTP daemon
 
-  Copyright (C) <2002-2005> Stefano Zacchiroli <zack@cs.unibo.it>
+  Copyright (C) <2002-2010> Stefano Zacchiroli <zack@cs.unibo.it>
+                <2010>      Arlen Cuss <celtic@sairyx.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU Library General Public License as
@@ -34,7 +35,7 @@ let url_decode url = Netencoding.Url.decode ~plus:true url
 let split_query_params query =
   let bindings = Pcre.split ~rex:bindings_sep query in
   match bindings with
-  | [] -> raise (Malformed_query query)
+  | [] -> []
   | bindings ->
       List.map
         (fun binding ->
@@ -151,6 +152,24 @@ let parse_headers ic =
   in
   parse_headers' []
 
+let parse_cookies raw_cookies =
+  let tokens =
+    let lexbuf = Lexing.from_string raw_cookies in
+    let rec aux acc =
+      match Cookie_lexer.token lexbuf with
+      | `EOF -> acc
+      | token -> aux (token :: acc)
+    in
+    List.rev (aux [])
+  in
+  let rec aux = function
+    | [ `ASSIGNMENT (n,v) ]           -> [ (n,v) ]
+    | `ASSIGNMENT (n,v) :: `SEP :: tl -> (n,v) :: aux tl
+    | _ -> prerr_endline ("failed to read raw cookies: '" ^ raw_cookies ^ "'");
+           raise (Malformed_cookies raw_cookies)
+  in
+  aux tokens
+
 let parse_request ic =
   let (meth, uri, version) = parse_request_fst_line ic in
   let path = parse_path uri in
